@@ -1,4 +1,4 @@
-/* $Id: rep_main.c,v 1.19 2004/07/25 14:21:13 tobiasb Exp $
+/* $Id: rep_main.c,v 1.20 2004/12/16 21:30:50 tobiasb Exp $
  *
  * ISDN accounting for isdn4linux. (Report-module)
  *
@@ -20,6 +20,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  * $Log: rep_main.c,v $
+ * Revision 1.20  2004/12/16 21:30:50  tobiasb
+ * New option -U: default source number for outgoing calls.
+ *
  * Revision 1.19  2004/07/25 14:21:13  tobiasb
  * New isdnrep option -m [*|/]number.  It multiplies or divide the cost of
  * each call by the given number.  `-m/1.16' for example displays the costs
@@ -311,7 +314,7 @@ static char  fnbuff[512] = "";
 static char  usage[]     = "%s: usage: %s [ -%s ]\n";
 static char  wrongdate[] = "unknown date: %s\n";
 static char  wrongxopt[] = "error in -x option starting at: %s\n";
-static char  options[]   = "abcd:f:him:nop:r:s:t:uvw:x:EF:L:M:NR:SV";
+static char  options[]   = "abcd:f:him:nop:r:s:t:uvw:x:EF:L:M:NR:SU:V";
 static char *linefmt     = "";
 static char *htmlreq     = NULL;
 static char *phonenumberarg = NULL;
@@ -331,7 +334,7 @@ int main(int argc, char *argv[], char *envp[])
 
 	recalc.mode = '\0'; recalc.prefix = UNKNOWN; recalc.input = NULL;
 	recalc.count = recalc.unknown = recalc.cheaper = 0;
-	modcost.mode = 0;
+	modcost.mode = defsrc.mode = 0;
 	select_summaries(sel_sums, NULL); /* default: all summaries */
 
 	/* we don't need this at the moment:
@@ -390,6 +393,21 @@ int main(int argc, char *argv[], char *envp[])
 		free(phonenumberarg);
 	}
 
+	if (defsrc.mode > 0 && *defsrc.number == '.') {
+		/* prefix country and area code from isdn.conf */
+		ptr = calloc(strlen(mycountry) + strlen(myarea) + strlen(defsrc.number),
+		             sizeof(char));
+		if (ptr == NULL) {
+			printf("No memory for complete default source number (-U)\n");
+			return 1;
+		}
+		strcat(ptr, mycountry);
+		strcat(ptr, myarea);
+		strcat(ptr, defsrc.number + 1);
+		free(defsrc.number);
+		defsrc.number = ptr;
+	}	
+
   if (htmlreq)
   {
 		send_html_request(myname,htmlreq);
@@ -560,6 +578,17 @@ static int parse_options(int argc, char *argv[], char *myname)
 			             *ptr = 0;		
 			           break;
 
+			case 'U' : defsrc.mode = (*optarg == '_') ? 2 : 1;
+			           ptr = optarg - 1 + defsrc.mode;
+			           /* mycountry and myarea may not yet known */
+			           defsrc.number = calloc(strlen(ptr) + 1, sizeof(char));
+			           if (!defsrc.number) {
+			             printf("No memory for default source number (-U)\n");
+			             return 1;
+			           }
+			           strcat(defsrc.number, ptr);
+			           break;
+
       case '?' : printf(usage, argv[0], argv[0], options);
                  return(1);
     } /* switch */
